@@ -28,7 +28,7 @@ KAtomicHighscores::KAtomicHighscores()
     KUser user;
     m_playerName =  user.property(KUser::FullName).toString().isEmpty() ? user.loginName() : user.property(KUser::FullName).toString();
 
-    m_hsFile = KSharedConfig::openConfig( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "highscores", KConfig::SimpleConfig);
+    m_hsFile = KSharedConfig::openConfig( QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + "highscores", KConfig::SimpleConfig);
 }
 
 bool KAtomicHighscores::addScore( int numMoves, const QString& levelSetName, int level )
